@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_KEYBOARD_INTERFACE_H
 #define WAYLAND_SERVER_KEYBOARD_INTERFACE_H
 
@@ -32,20 +18,29 @@ namespace Server
 class SeatInterface;
 class SurfaceInterface;
 
+/**
+ * @brief Resource for the wl_keyboard interface.
+ *
+ **/
 class KWAYLANDSERVER_EXPORT KeyboardInterface : public Resource
 {
     Q_OBJECT
 public:
     virtual ~KeyboardInterface();
 
+    /**
+     * @returns the focused SurfaceInterface on this keyboard resource, if any.
+     **/
     SurfaceInterface *focusedSurface() const;
 
 private:
     void setFocusedSurface(SurfaceInterface *surface, quint32 serial);
     void setKeymap(int fd, quint32 size);
+    void setKeymap(const QByteArray &content);
     void updateModifiers(quint32 depressed, quint32 latched, quint32 locked, quint32 group, quint32 serial);
     void keyPressed(quint32 key, quint32 serial);
     void keyReleased(quint32 key, quint32 serial);
+    void repeatInfo(qint32 charactersPerSecond, qint32 delay);
     friend class SeatInterface;
     explicit KeyboardInterface(SeatInterface *parent, wl_resource *parentResource);
 
